<html>
<head>
<title>dqqnqI</title>
<meta http-equiv="Content-Type" content="text/html;charset=sjis">
</head>

<?cs if:Flag ?>

<?cs if:IsMobile ?>

<body>
<b><?cs var:html_escape(LongErrorStr) ?></b>
<p><a href="<?cs if:KEY ?><?cs var:html_escape(CGIURI) ?>/r.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(KEY) ?>/i<?cs else ?><?cs var:html_escape(BBSURI) ?>/i/<?cs /if ?>">[h</a></p>

<?cs else ?>

<body bgcolor="#FFFFFF">
<!-- 2ch_X:error -->
<font size=+1 color=#FF0000><b>dqqnqF<?cs var:LongErrorStr ?></b></font>
<ul>
<br>
zXg<b><?cs var:html_escape(Host) ?></b><br><br>
OF<b><?cs var:Name ?></b><br>
E-mailF<?cs var:html_escape(Mail) ?><br>
eF<br><?cs var:Message ?><br><br>
</ul>
<small>
[h͂ōs܂B
<a href="<?cs var:html_escape(BBSURI) ?>"> GO! </a>
<hr>
<div align=right><?cs var:html_escape(VERSION) ?></div>
</small>

<?cs /if ?>

<?cs else ?>

<body bgcolor="#efefef">
<b><font color=red face="Century Gothic" size=+2>ERROR!!</font>
<font face="MS UI Gothic" size=+2> <?cs var:html_escape(Subject) ?></b></font>
<hr>
<blockquote>
<b><?cs var:LongErrorStr ?></b>
</blockquote>
<hr>
<table border=0 width=100%>
<tr>
<td>
</td>
<td align=right>
<b><small><?cs var:html_escape(VERSION) ?></small></b>
</td>
</tr>
</table>

<?cs /if ?>

</body></html>
